/* Schedwi
   Copyright (C) 2007-2015 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* sql_link.h -- functions to retrieve link details from the database */

#ifndef _SQL_LINK_H
#define _SQL_LINK_H

#include <schedwi.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern int sql_link_are_resolved OF((int workload_date,
				unsigned long long int job_id,
				void (*error_func)(void *, const char *, int),
				void *user_data_error_func));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* sql_link.h */

/*-----------------============== End Of File ==============-----------------*/
